#pragma glslify: import('../common.glsl')

#define BASE_BARS 24.0
#define SCALE 2.0
#define COLOR_SCALE 1.7
#define ALPHA 0.5

float circle(vec2 center, vec2 point, float radius) {
  vec2 dist = point - center;
  return 1. - smoothstep(radius-0.05, radius+0.05, dot(dist, dist) * 3.);
}

vec4 color(vec2 uv) {
    vec2 intUV = floor(uv * BASE_BARS) / BASE_BARS;
    float height = getFrequencyValue(intUV.x*(u_resolution.y/u_resolution.x), FREQ_AMPLITUDE) * SCALE;

    if (height > max(intUV.y, 0.05)) {
      return vec4(getTweenedTexture(u_palette, intUV.y * COLOR_SCALE).rgb, 1.0);
    }

    return vec4(vec3(.1), 0.0);
}

void main()
{
  vec2 uv = gl_FragCoord.xy / u_resolution.xy;
  uv.x *= u_resolution.x/u_resolution.y;
  vec2 tiledUV = vec2(fract(uv.x * BASE_BARS), fract(uv.y * BASE_BARS));
  gl_FragColor = vec4(vec3(circle(vec2(.5), tiledUV, .5)), ALPHA);
  gl_FragColor *= vec4(color(uv).rgb, 0.0);
}
